import React from "react";
import classes from "./MainLogin.module.css";
import { Field, reduxForm } from "redux-form";
import { Input } from "../../../common/FormControls/FormsControls";
import { required } from "../../../common/FormControls/validators";
import { Redirect } from "react-router";




const MainLogin = (props) => {
  let onSubmit = (formData) => {
    props.auth(formData.login, formData.password);
  };

  if (props.loggedIn) {
    return <Redirect to={"/"} />
  }

  return (
    <div className={classes.divLoginHolder}>
      <div className={classes.divLogin}>
        <h1>Authorization</h1>
        <div>
          <MainLoginReduxForm onSubmit={onSubmit} />
        </div>
      </div>
    </div>
  );
};

const MainLoginForm = (props) => {
  return (
    <form onSubmit={props.handleSubmit}>
      <div>
        <div>Login</div>

        <Field placeholder={"Login"} validate={[required]} name={"login"} component={Input} />
      </div>
      <div>
        <div>Password</div>

        <Field placeholder={"Password"} validate={[required]} type={"password"} name={"password"} component={Input} />
      </div>
      <div>
        <button className={classes.authButton}>Login</button>
      </div>
    </form>
  );
}

const MainLoginReduxForm = reduxForm({
  // a unique name for the form
  form: "login",
})(MainLoginForm);


export default MainLogin;
