import { actionPromise, shopGQL } from "./promiseReducer";

function authReducer(state, action) {
  if (state === undefined) {
    if (localStorage.token) {
      action.token = localStorage.token;
      action.type = "LOGIN";
    } else {
      return {};
    }
  }
  if (action.type === "LOGIN") {
    localStorage.token = action.token;
    let { 1: tokenAverage } = action.token.split(".");
    let decodedToken = atob(tokenAverage);
    let parsedToken = JSON.parse(decodedToken);
    return { token: action.token, payload: parsedToken };
  }
  if (action.type === "LOGOUT") {
    console.log("ЛОГАУТ");
    localStorage.removeItem("token");
    return {};
  }
  return state;
}

const actionGetToken = (login, password) =>
  actionPromise(
    "getToken",
    shopGQL(
      `query login($login:String, $password:String){
                                                  login(login: $login, password: $password)
                                              }`,
      { login, password }
    )
  );

const actionAuthLogin = (token) => ({ type: "LOGIN", token });
export const actionLogout = () => ({ type: "LOGOUT" })

export const actionFullLogin = (login, password) => async (dispatch) => {
  let payload = await dispatch(actionGetToken(login, password));
  if (payload.data.login) {
    dispatch(actionAuthLogin(payload.data.login));
  }
};

const actionRegister = (login, password) =>
  actionPromise(
    "register",
    shopGQL(
      `mutation reg($query:UserInput){
                  UserUpsert(user:$query){
                      _id login
                  }
                  }`,
      { query: { login, password } }
    )
  );

export const actionFullRegister = (login, password) => async (dispatch) => {
  let payload = await dispatch(actionRegister(login, password));
  if (payload.data.UserUpsert != null) {
    await dispatch(actionFullLogin(login, password));
  }
};

export default authReducer;