const promiseReducer = function (
  state = {},
  { type, status, payload, error, name }
) {
  if (type === "PROMISE") {
    return {
      ...state,
      [name]: { status, payload, error },
    };
  }
  return state;
};

const actionPending = (name) => ({
  type: "PROMISE",
  status: "PENDING",
  name,
});
const actionResolved = (name, payload) => ({
  type: "PROMISE",
  status: "RESOLVED",
  name,
  payload,
});
const actionRejected = (name, error) => ({
  type: "PROMISE",
  status: "REJECTED",
  name,
  error,
});

export const actionPromise = (name, promise) => async (dispatch) => {
  dispatch(actionPending(name));
  try {
    let payload = await promise;
    dispatch(actionResolved(name, payload));
    return payload;
  } catch (error) {
    dispatch(actionRejected(name, error));
  }
};

const getGQL =
  (url) =>
  (query, variables = {}) => {
    let headers;
    if (localStorage.token) {
      headers = {
        "Content-Type": "application/json",
        Authorization: "Bearer " + localStorage.token,
      };
    } else {
      headers = {
        "Content-Type": "application/json",
      };
    }
    return fetch(url, {
      method: "POST",
      headers,
      body: JSON.stringify({ query, variables }),
    }).then((res) => res.json());
  };

export let shopGQL = getGQL("http://shop-roles.asmer.fs.a-level.com.ua/graphql");

export const actionRootCategories = () =>
  actionPromise(
    "rootCategories",
    shopGQL(
      `
                  query cats($query:String){
                    CategoryFind(query:$query){
                      _id name
                    }
                  }
              `,
      { query: JSON.stringify([{ parent: null }]) }
    )
  );

export const actionCategoryById = (_id) =>
  actionPromise(
    "catById",
    shopGQL(
      `query catById($query:String){
                                                CategoryFindOne(query:$query){
                                                  _id name goods{
                                                    _id name price description images{
                                                      url
                                                    }
                                                  }
                                                }
                                              }`,
      { query: JSON.stringify([{ _id }]) }
    )
  );

export const actionGoodById = (_id) =>
  actionPromise(
    "goodById",
    shopGQL(
      `query goodById($query:String){
                                                GoodFindOne(query:$query){
                                                  _id name price description images {
                                                      url
                                                  }
                                                }
                                              }`,
      { query: JSON.stringify([{ _id }]) }
    )
  );

export default promiseReducer;
